/** ###################################################################
**     THIS COMPONENT MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename    : LEDR.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : LED
**     Version     : Component 01.063, Driver 01.00, CPU db: 3.00.000
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-12-29, 14:20, # CodeGen: 231
**     Abstract    :
**          This component implements a universal driver for a single LED.
**     Settings    :
**          Component name                                 : LEDR
**          Turned On with initialization                  : no
**          HW Interface                                   : 
**            On/Off                                       : Disabled
**            PWM                                          : Enabled
**              PWM                                        : PWM
**            High Value means ON                          : no
**          Shell                                          : Enabled
**            Shell                                        : FSSH1
**            Utility                                      : UTIL1
**     Contents    :
**         On           - void LEDR_On(void);
**         Off          - void LEDR_Off(void);
**         Neg          - void LEDR_Neg(void);
**         Get          - byte LEDR_Get(void);
**         Put          - void LEDR_Put(byte val);
**         Init         - void LEDR_Init(void);
**         Deinit       - void LEDR_Deinit(void);
**         ParseCommand - byte LEDR_ParseCommand(const unsigned char *cmd, bool *handled, const...
**         SetRatio16   - void LEDR_SetRatio16(word ratio);
**
**     License   :  Open Source (LGPL)
**     Copyright : (c) Copyright Erich Styger, 2012, all rights reserved.
**     This an open source software implementing an LED driver using Processor Expert.
**     This is a free software and is opened for education, research and commercial developments under license policy of following terms:
**     * This is a free software and there is NO WARRANTY.
**     * No restriction on use. You can use, modify and redistribute it for personal, non-profit or commercial product UNDER YOUR RESPONSIBILITY.
**     * Redistributions of source code must retain the above copyright notice.
** ###################################################################*/

/* MODULE LEDR. */

#include "LEDR.h"

uint16_t LEDR_currPWM; /* current 16bit PWM value */

static uint8_t PrintStatus(const FSSH1_StdIOType *io) {
  FSSH1_SendStatusStr((unsigned char*)"LEDR", (unsigned char*)"\r\n", io->stdOut);
  if (LEDR_Get()!=0) {
    FSSH1_SendStatusStr((unsigned char*)"  on", (unsigned char*)"yes\r\n", io->stdOut);
  } else {
    FSSH1_SendStatusStr((unsigned char*)"  on", (unsigned char*)"no\r\n", io->stdOut);
  }
  {
    uint8_t buf[6];

    FSSH1_SendStatusStr((unsigned char*)"  pwm", (unsigned char*)"0x", io->stdOut);
    buf[0] = '\0';
    UTIL1_strcatNum16Hex(buf, sizeof(buf), LEDR_currPWM);
    UTIL1_strcat(buf, sizeof(buf), (unsigned char*)"\r\n");
    FSSH1_SendStr(buf, io->stdOut);
  }
  return ERR_OK;
}

static uint8_t PrintHelp(const FSSH1_StdIOType *io) {
  /* list your local help here */
  FSSH1_SendHelpStr((unsigned char*)"LEDR", (unsigned char*)"Group of LEDR commands\r\n", io->stdOut);
  FSSH1_SendHelpStr((unsigned char*)"  help|status", (unsigned char*)"Print help or status information\r\n", io->stdOut);
  FSSH1_SendHelpStr((unsigned char*)"  on|off|neg", (unsigned char*)"Turns it on, off or toggle it\r\n", io->stdOut);
  FSSH1_SendHelpStr((unsigned char*)"  duty <value>", (unsigned char*)"Set duty value (unsigned, hex or % value)\r\n", io->stdOut);
  return ERR_OK;
}

/*
** ===================================================================
**     Method      :  LEDR_ParseCommand (component LED)
**
**     Description :
**         Shell Command Line parser
**     Parameters  :
**         NAME            - DESCRIPTION
**       * cmd             - Pointer to command string
**       * handled         - Pointer to variable which tells if
**                           the command has been handled or not
**       * io              - Pointer to I/O structure
**     Returns     :
**         ---             - Error code
** ===================================================================
*/
byte LEDR_ParseCommand(const unsigned char *cmd, bool *handled, const FSSH1_StdIOType *io)
{
  if (UTIL1_strcmp((char*)cmd, FSSH1_CMD_HELP)==0 || UTIL1_strcmp((char*)cmd, "LEDR help")==0) {
    *handled = TRUE;
    return PrintHelp(io);
  } else if ((UTIL1_strcmp((char*)cmd, FSSH1_CMD_STATUS)==0) || (UTIL1_strcmp((char*)cmd, "LEDR status")==0)) {
    *handled = TRUE;
    return PrintStatus(io);
  } else if (UTIL1_strcmp((char*)cmd, "LEDR on")==0) {
    *handled = TRUE;
    LEDR_On();
    return ERR_OK;
  } else if (UTIL1_strcmp((char*)cmd, "LEDR off")==0) {
    *handled = TRUE;
    LEDR_Off();
    return ERR_OK;
  } else if (UTIL1_strcmp((char*)cmd, "LEDR neg")==0) {
    *handled = TRUE;
    LEDR_Neg();
    return ERR_OK;
  } else if (UTIL1_strncmp((char*)cmd, "LEDR duty ", sizeof("LEDR duty ")-1)==0) {
    uint16_t value;
    uint8_t res;
    const unsigned char *p;

    p = cmd+sizeof("LEDR duty ")-1;
    if (p[0]=='0' && p[1]=='x') { /* hexadecimal */
      res = UTIL1_ScanHex16uNumber(&p, &value);
    } else { /* decimal */
      res = UTIL1_ScanDecimal16uNumber(&p, &value);
    }
    if (*p=='%' && value<=100) { /* percent value */
      value = (uint16_t)((0xFFFFUL*value)/100);
    }
    if (res!=ERR_OK) {
      FSSH1_SendStr((unsigned char*)"*** invalid number format! Try e.g. 10, 0x10 or 10%\r\n", io->stdErr);
      return ERR_FAILED;
    }
    *handled = TRUE;
    LEDR_SetRatio16(value);
    return ERR_OK;
  }
  return ERR_OK;
}

/*
** ===================================================================
**     Method      :  LEDR_On (component LED)
**
**     Description :
**         This turns the LED on.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/*
** ===================================================================
**     Method      :  LEDR_Off (component LED)
**
**     Description :
**         This turns the LED off.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/*
void LEDR_Off(void)
{
  *** This method is implemented as macro in the header file
}
*/

/*
** ===================================================================
**     Method      :  LEDR_Neg (component LED)
**
**     Description :
**         This negates/toggles the LED
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/*
void LEDR_Neg(void)
{
  *** This method is implemented as macro in the header file
}
*/

/*
** ===================================================================
**     Method      :  LEDR_Get (component LED)
**
**     Description :
**         This returns logical 1 in case the LED is on, 0 otherwise.
**     Parameters  : None
**     Returns     :
**         ---             - Status of the LED (on or off)
** ===================================================================
*/
/*
byte LEDR_Get(void)
{
  *** This method is implemented as macro in the header file
}
*/

/*
** ===================================================================
**     Method      :  LEDR_Init (component LED)
**
**     Description :
**         Performs the LED driver initialization.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/*
void LEDR_Init(void)
{
  *** This method is implemented as macro in the header file
}
*/

/*
** ===================================================================
**     Method      :  LEDR_Put (component LED)
**
**     Description :
**         Turns the LED on or off.
**     Parameters  :
**         NAME            - DESCRIPTION
**         val             - value to define if the LED has to be on or
**                           off.
**     Returns     : Nothing
** ===================================================================
*/
/*
void LEDR_Put(byte val)
{
  *** This method is implemented as macro in the header file
}
*/

/*
** ===================================================================
**     Method      :  LEDR_Deinit (component LED)
**
**     Description :
**         Deinitializes the driver
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void LEDR_Deinit(void)
{
}

/*
** ===================================================================
**     Method      :  LEDR_SetRatio16 (component LED)
**
**     Description :
**         Method to specify the duty cylce. If using a PWM pin, this
**         means the duty cycle is set. For On/off pins, values smaller
**         0x7FFF means off, while values greater means on.
**     Parameters  :
**         NAME            - DESCRIPTION
**         ratio           - Ratio value, where 0 means 'off' and
**                           0xffff means 'on'
**     Returns     : Nothing
** ===================================================================
*/
void LEDR_SetRatio16(word ratio)
{
  LEDR_currPWM = ratio;
  (void)Inhr3_SetRatio16(ratio);
}

/* END LEDR. */

/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.03]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
